#
# spec file for package python-Flask-Caching
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-Flask-Caching
Version:        2.3.1
Release:        1.1
Summary:        Adds caching support to your Flask application
License:        BSD-3-Clause
URL:            https://github.com/sh4nks/flask-caching
Source:         https://files.pythonhosted.org/packages/source/F/Flask-Caching/flask_caching-%{version}.tar.gz
BuildRequires:  %{python_module Flask}
BuildRequires:  %{python_module asgiref >= 3.2}
BuildRequires:  %{python_module cachelib >= 0.9}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pylibmc}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module redis >= 5}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  memcached-devel
BuildRequires:  python-rpm-macros
Requires:       python-Flask
Requires:       python-cachelib >= 0.9
BuildArch:      noarch
%python_subpackages

%description
Adds caching support to your Flask application. Continuation of the Flask-Cache
Extension.

%prep
%setup -q -n flask_caching-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/flask_caching
%{python_sitelib}/[Ff]lask[_-][Cc]aching-%{version}.dist-info

%changelog
* Tue May  6 2025 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.3.1:
  * Relax cachelib version to allow latest releases
  * Drop python 3.7 support
  * python 3.11 officially supported
  * Fix issue causing args_to_ignore to not work with
    flask_caching.Cache.memoize decorator when keyword arguments were used in
    the decorated function call
  * fix type signature in flask_caching.utils.make_template_fragment_key.
  * support Flask 3
  * bug fix: make the make_cache_key attributed of decorated view functions
    writeable.
  * fix bug where flask_caching.backends.RedisSentinelCache.get_many would
    query wrong host&port combination.
  * Remove flask_caching.backends.FileSystemCache method overrides.
  * Add proxy to underlaying has method of cache clients.
  * flask_caching.backends.FileSystemCache now stores timestamps in a
    universal (non-frammed) way following the lastest version of
    cachelib.FileSystemCache.
  * Add suport for cached/memoized generators.
  * Add support for Flask 2.0 async.
  * Cachelib is now used as backend.
  * Drop support for python 3.6.
  * Add support for dynamic cache timeouts
  * Fix bug in CACHE_OPTIONS reading for redis in RedisSentinelCache.
  * A GoogleCloudStorageCache backend has been added to the user contributed
    caching backends.
  * Important: The way caching backends are loaded have been refactored.
    Instead of passing the name of the initialization function one can now
    use the full path to the caching backend class.
  * UWSGICache is not officially supported anymore and moved to the user
    contributed backends.
  * Fix add() in RedisCache without a timeout.
  * Fix error in how the FileSystemCache counts the number of files.
  * Fix kwargs not being passed on in function _memoize_make_cache_key.
  * Add a Redis Cluster Mode caching backend.
  * Add an option to include the functions source code when generating the
    cache key.
  * Completely control the way how cache keys are generated.
- Switch to pyproject macros.
- Support both uppercased and normalized metadata directory names.
* Wed Jun  3 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * be more specific in %%files section
- update to version 1.9.0:
  * Add an option to include the functions source code when generating
    the cache key. PR `#156
    <https://github.com/sh4nks/flask-caching/pull/156>`_.
  * Add an feature that allows one to completely control the way how
    cache keys are generating. For example, one can now implement a
    function that generates cache the keys based on the POST-based
    requests.  PR `#159
    <https://github.com/sh4nks/flask-caching/pull/159>`_.
  * Fix the cache backend naming collisions by renaming them from
    "simple" to "simplecache", "null" to "nullcache" and "filesystem"
    to "filesystemcache".
  * Explicitly pass the "default_timeout" to "RedisCache" from
    "RedisSentinelCache".
  * Use "os.replace" instead of werkzeug's "rename" due to Windows
    raising an "OSError" if the dst file already exist.
  * Documentation updates and fixes.
* Sat May  2 2020 Petr Cervinka <petr@cervinka.net>
- Initial version
